// SPDX-License-Identifier: MIT

use axum::{response::IntoResponse, routing::post, Router};

use crate::common::{
    exec_command, CheckAuthRestApi, RestApiPermissionPoweroff, RestApiPermissionReboot,
};
use crate::error::ErrorStringResult;

pub fn routes() -> Router {
    Router::new()
        .route("/api/reboot", post(restapi_reboot))
        .route("/api/poweroff", post(restapi_poweroff))
}

/// POST "/api/reboot"
/// - Access: reboot
/// - Input: None
/// - Output: None
async fn restapi_reboot(_auth: CheckAuthRestApi<RestApiPermissionReboot>) -> ErrorStringResult {
    exec_command(&["power.sh", "reboot"]).await?;
    Ok(().into_response())
}

/// POST "/api/poweroff"
/// - Access: poweroff
/// - Input: None
/// - Output: None
async fn restapi_poweroff(_auth: CheckAuthRestApi<RestApiPermissionPoweroff>) -> ErrorStringResult {
    exec_command(&["power.sh", "poweroff"]).await?;
    Ok(().into_response())
}
